Page Menu
Home
FreeBSD
Search
Configure Global Search
Log In
Files
F105535000
D35973.id108661.diff
No One
Temporary
Actions
View File
Edit File
Delete File
View Transforms
Subscribe
Mute Notifications
Flag For Later
Award Token
Size
1 KB
Referenced Files
None
Subscribers
None
D35973.id108661.diff
View Options
Index: stand/i386/loader/main.c
===================================================================
--- stand/i386/loader/main.c
+++ stand/i386/loader/main.c
@@ -387,7 +387,7 @@
#ifdef LOADER_ZFS_SUPPORT
if (new_currdev.dd.d_dev->dv_type == DEVT_ZFS)
- init_zfs_boot_options(zfs_fmtdev(&new_currdev.dd));
+ init_zfs_boot_options(devformat(&new_currdev.dd));
#endif
env_setenv("currdev", EV_VOLATILE, i386_fmtdev(&new_currdev),
Index: stand/libsa/zfs/zfs.c
===================================================================
--- stand/libsa/zfs/zfs.c
+++ stand/libsa/zfs/zfs.c
@@ -1583,7 +1583,7 @@
rv = 0;
/* This device is not set as currdev, mount us private copy. */
if (mount == NULL)
- rv = zfs_mount(zfs_fmtdev(&dev->dd), NULL, (void **)&mount);
+ rv = zfs_mount(devformat(&dev->dd), NULL, (void **)&mount);
if (rv == 0) {
f->f_devdata = mount;
Index: stand/userboot/userboot/main.c
===================================================================
--- stand/userboot/userboot/main.c
+++ stand/userboot/userboot/main.c
@@ -260,7 +260,7 @@
bzero(&zdev, sizeof(zdev));
zdev.dd.d_dev = &zfs_dev;
- init_zfs_boot_options(zfs_fmtdev(&zdev.dd));
+ init_zfs_boot_options(devformat(&zdev.dd));
dd = &zdev.dd;
} else
#endif
File Metadata
Details
Attached
Mime Type
text/plain
Expires
Wed, Dec 18, 9:20 AM (20 h, 45 m)
Storage Engine
blob
Storage Format
Raw Data
Storage Handle
15483766
Default Alt Text
D35973.id108661.diff (1 KB)
Attached To
Mode
D35973: stand: Replace zfs_fmtdev with generic devformat()
Attached
Detach File
Event Timeline
Log In to Comment
Index: stand/i386/zfsboot/zfsboot.c
===================================================================
--- stand/i386/zfsboot/zfsboot.c
+++ stand/i386/zfsboot/zfsboot.c
@@ -222,11 +222,11 @@
devdesc.d_partition >= 0 ? devdesc.d_partition : 0xff);
/*
* zfs_fmtdev() can be called only after dv_init
*/
if (bdev != NULL && bdev->dd.d_dev->dv_type == DEVT_ZFS) {
/* set up proper device name string for ZFS */
- strncpy(boot_devname, zfs_fmtdev(&bdev->dd), sizeof (boot_devname));
+ strncpy(boot_devname, devformat(&bdev->dd), sizeof (boot_devname));
if (zfs_get_bootonce(bdev, OS_BOOTONCE, cmd,
sizeof(cmd)) == 0) {
nvlist_t *benv;
@@ -222,11 +222,11 @@
devdesc.d_partition >= 0 ? devdesc.d_partition : 0xff);
/*
- * zfs_fmtdev() can be called only after dv_init
+ * devformat() can be called only after dv_init
*/
if (bdev != NULL && bdev->dd.d_dev->dv_type == DEVT_ZFS) {